@@ -134,13 +134,6 @@
 /* .IP "\fBtls_fast_shutdown_enable (yes)\fR"
 /*	A workaround for implementations that hang Postfix while shutting
 /*	down a TLS session, until Postfix times out.
-/* .PP
-/*	Available in Postfix 3.9, 3.8.1, 3.7.6, 3.6.10, 3.5.20 and later:
-/* .IP "\fBtls_config_file (default)\fR"
-/*	Optional configuration file with baseline OpenSSL settings.
-/* .IP "\fBtls_config_name (empty)\fR"
-/*	The application name passed by Postfix to OpenSSL library
-/*	initialization functions.
 /* STARTTLS SERVER CONTROLS
 /* .ad
 /* .fi
@@ -279,6 +272,12 @@
 /*	value.
 /* .IP "\fBtlsproxy_client_scert_verifydepth ($smtp_tls_scert_verifydepth)\fR"
 /*	The verification depth for remote TLS server certificates.
+/* .IP "\fBtlsproxy_client_security_level ($smtp_tls_security_level)\fR"
+/*	The default TLS security level for the Postfix \fBtlsproxy\fR(8)
+/*	client.
+/* .IP "\fBtlsproxy_client_policy_maps ($smtp_tls_policy_maps)\fR"
+/*	Optional lookup tables with the Postfix \fBtlsproxy\fR(8) client TLS
+/*	security policy by next-hop destination.
 /* .IP "\fBtlsproxy_client_use_tls ($smtp_use_tls)\fR"
 /*	Opportunistic mode: use TLS when a remote server announces TLS
 /*	support.
@@ -288,22 +287,6 @@
 /*	Optional lookup tables with the Postfix \fBtlsproxy\fR(8) client TLS
 /*	usage policy by next-hop destination and by remote TLS server
 /*	hostname.
-/* .PP
-/*	Available in Postfix version 3.4-3.6:
-/* .IP "\fBtlsproxy_client_level ($smtp_tls_security_level)\fR"
-/*	The default TLS security level for the Postfix \fBtlsproxy\fR(8)
-/*	client.
-/* .IP "\fBtlsproxy_client_policy ($smtp_tls_policy_maps)\fR"
-/*	Optional lookup tables with the Postfix \fBtlsproxy\fR(8) client TLS
-/*	security policy by next-hop destination.
-/* .PP
-/*	Available in Postfix version 3.7 and later:
-/* .IP "\fBtlsproxy_client_security_level ($smtp_tls_security_level)\fR"
-/*	The default TLS security level for the Postfix \fBtlsproxy\fR(8)
-/*	client.
-/* .IP "\fBtlsproxy_client_policy_maps ($smtp_tls_policy_maps)\fR"
-/*	Optional lookup tables with the Postfix \fBtlsproxy\fR(8) client TLS
-/*	security policy by next-hop destination.
 /* OBSOLETE STARTTLS SUPPORT CONTROLS
 /* .ad
 /* .fi
@@ -315,11 +298,6 @@
 /* .IP "\fBtlsproxy_enforce_tls ($smtpd_enforce_tls)\fR"
 /*	Mandatory TLS: announce STARTTLS support to remote SMTP clients, and
 /*	require that clients use TLS encryption.
-/* .IP "\fBtlsproxy_client_use_tls ($smtp_use_tls)\fR"
-/*	Opportunistic mode: use TLS when a remote server announces TLS
-/*	support.
-/* .IP "\fBtlsproxy_client_enforce_tls ($smtp_enforce_tls)\fR"
-/*	Enforcement mode: require that SMTP servers use TLS encryption.
 /* RESOURCE CONTROLS
 /* .ad
 /* .fi
@@ -945,7 +923,7 @@ static void tlsp_strategy(TLSP_STATE *state)
      * block. In practice, postscreen(8) limits the number of client
      * commands, and thus postscreen(8)'s output will fit in a kernel buffer.
      * A remote SMTP server is not supposed to flood the local SMTP client
-     * with massive replies; if it does, then the local SMTP client should
+     * with massive replies; it it does, then the local SMTP client should
      * deal with it.
      */
     if (NBBIO_WRITE_PEND(plaintext_buf) > 0) {
@@ -993,7 +971,7 @@ static void tlsp_ciphertext_event(int event, void *context)
     TLSP_STATE *state = (TLSP_STATE *) context;
 
     /*
-     * Without a TLS equivalent of the NBBIO layer, we must decode the events
+     * Without a TLS quivalent of the NBBIO layer, we must decode the events
      * ourselves and do the ciphertext I/O. Then, we can decide if we want to
      * read or write more ciphertext.
      */
@@ -1235,12 +1213,6 @@ static TLS_APPL_STATE *tlsp_client_init(TLS_CLIENT_PARAMS *tls_params,
     init_buf = vstring_alloc(100);
     init_key = tls_proxy_client_init_serialize(attr_print_plain, init_buf,
 					       init_props);
-#define TLSP_CLIENT_INIT_RETURN(retval) do { \
-	vstring_free(init_buf); \
-	vstring_free(param_buf); \
-	return (retval); \
-    } while (0)
-
     if (tlsp_pre_jail_done == 0) {
 	if (tlsp_pre_jail_client_param_key == 0
 	    || tlsp_pre_jail_client_init_key == 0) {
@@ -1258,12 +1230,9 @@ static TLS_APPL_STATE *tlsp_client_init(TLS_CLIENT_PARAMS *tls_params,
      * TLS_APPL_STATE instance; this makes a mismatch of TLS_CLIENT_PARAMS
      * settings problematic.
      */
-    else if (tlsp_pre_jail_client_param_key == 0
-	     || tlsp_pre_jail_client_init_key == 0) {
-	msg_warn("TLS client role is disabled by configuration");
-	TLSP_CLIENT_INIT_RETURN(0);
-    } else if (!been_here_fixed(tlsp_params_mismatch_filter, param_key)
-	       && strcmp(tlsp_pre_jail_client_param_key, param_key) != 0) {
+    if (tlsp_pre_jail_done
+	&& !been_here_fixed(tlsp_params_mismatch_filter, param_key)
+	&& strcmp(tlsp_pre_jail_client_param_key, param_key) != 0) {
 	msg_warn("request from tlsproxy client with unexpected settings");
 	tlsp_log_config_diff(tlsp_pre_jail_client_param_key, param_key);
 	log_hints = 1;
@@ -1338,7 +1307,9 @@ static TLS_APPL_STATE *tlsp_client_init(TLS_CLIENT_PARAMS *tls_params,
 			 SSL_MODE_ENABLE_PARTIAL_WRITE
 			 | SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
     }
-    TLSP_CLIENT_INIT_RETURN(appl_state);
+    vstring_free(init_buf);
+    vstring_free(param_buf);
+    return (appl_state);
 }
 
 /* tlsp_close_event - pre-handshake plaintext-client close event */
@@ -1385,12 +1356,6 @@ static void tlsp_get_request_event(int event, void *context)
     /*
      * Receive the initial request attributes. Receive the remainder after we
      * figure out what role we are expected to play.
-     * 
-     * The tlsproxy server does not enforce per-request read/write deadlines or
-     * minimal data rates. Instead, the tlsproxy server relies on the
-     * tlsproxy client to enforce these context-dependent limits. When a
-     * tlsproxy client decides to time out, it will close its end of the
-     * tlsproxy stream, and the tlsproxy server will handle that immediately.
      */
     if (event != EVENT_READ
 	|| attr_scan(plaintext_stream, ATTR_FLAG_STRICT,
@@ -1472,7 +1437,6 @@ static void tlsp_get_request_event(int event, void *context)
 				TLSP_INIT_TIMEOUT, (void *) state);
 	return;
     } else {
-	state->flags |= TLSP_FLAG_DO_HANDSHAKE;
 	tlsp_request_read_event(plaintext_fd, tlsp_get_fd_event,
 				TLSP_INIT_TIMEOUT, (void *) state);
 	return;
